@@ -15,7 +15,7 @@ function _fnCreateTr ( oSettings, iRow, nTrIn, anTds )
 		rowData = row._aData,
 		cells = [],
 		nTr, nTd, oCol,
-		i, iLen;
+		i, iLen, create;
 
 	if ( row.nTr === null )
 	{
@@ -36,8 +36,9 @@ function _fnCreateTr ( oSettings, iRow, nTrIn, anTds )
 		for ( i=0, iLen=oSettings.aoColumns.length ; i<iLen ; i++ )
 		{
 			oCol = oSettings.aoColumns[i];
+			create = nTrIn ? false : true;
 
-			nTd = nTrIn ? anTds[i] : document.createElement( oCol.sCellType );
+			nTd = create ? document.createElement( oCol.sCellType ) : anTds[i];
 			nTd._DT_CellIndex = {
 				row: iRow,
 				column: i
@@ -46,9 +47,9 @@ function _fnCreateTr ( oSettings, iRow, nTrIn, anTds )
 			cells.push( nTd );
 
 			// Need to create the HTML if new, or if a rendering function is defined
-			if ( (!nTrIn || oCol.mRender || oCol.mData !== i) &&
+			if ( create || ((!nTrIn || oCol.mRender || oCol.mData !== i) &&
 				 (!$.isPlainObject(oCol.mData) || oCol.mData._ !== i+'.display')
-			) {
+			)) {
 				nTd.innerHTML = _fnGetCellData( oSettings, iRow, i, 'display' );
 			}
 
