@@ -24,7 +24,7 @@ describe('rows - row.add()', function() {
 		table.search('Fred Johnson').draw();
 
 		if (
-			$('#example_info').text() != 'Showing 1 to 1 of 1 entries (filtered from 58 total entries)' ||
+			$('div.dataTables_info').text() != 'Showing 1 to 1 of 1 entries (filtered from 58 total entries)' ||
 			$('#example tbody tr:eq(0) td:eq(0)').text() != 'Fred Johnson'
 		) {
 			return false;
@@ -40,7 +40,7 @@ describe('rows - row.add()', function() {
 			let table = $('#example').DataTable();
 			table.row.add(row);
 			expect(table.rows().count()).toBe(58);
-			expect($('#example_info').text()).toBe('Showing 1 to 10 of 57 entries');
+			expect($('div.dataTables_info').text()).toBe('Showing 1 to 10 of 57 entries');
 		});
 
 		dt.html('basic');
@@ -54,7 +54,7 @@ describe('rows - row.add()', function() {
 		dt.html('basic');
 		it('Add row as an Object', function() {
 			let table = $('#example').DataTable({
-				columns: dt.testColumns
+				columns: dt.getTestColumns()
 			});
 			table.row
 				.add({
@@ -82,4 +82,32 @@ describe('rows - row.add()', function() {
 			expect(isFredThere()).toBe(true);
 		});
 	});
+
+	describe('Adding new row to HTML5 attr sourced orthogonal table', function() {
+		dt.html('html5');
+
+		it('Add row as a Node', function() {
+			let table = $('#example').DataTable();
+			table
+				.row.add({
+					0: {
+						display: 'Jadzia',
+						'@data-filter': 'Dax'
+					},
+					1: {
+						display: 'Know it all',
+						'@data-sort': '1'
+					},
+					2: 'DS9',
+					3: '213',
+					4: '2012/03/29',
+					5: '0'
+				})
+				.search('Dax')
+				.draw();
+
+			expect($('#example tbody td:eq(0)').text()).toBe('Jadzia');
+		} );
+	});
 });
+
