@@ -4,15 +4,15 @@ describe('toArray()', function() {
 		css: ['datatables']
 	});
 
+	let table;
+
 	describe('Check the defaults', function() {
 		dt.html('basic');
 		it('Exists and is a function', function() {
-			let table = $('#example').DataTable();
+			table = $('#example').DataTable();
 			expect(typeof table.toArray).toBe('function');
 		});
-
 		it('Returns API instance', function() {
-			let table = $('#example').DataTable();
 			expect(table.toArray() instanceof Array).toBe(true);
 		});
 	});
@@ -20,16 +20,14 @@ describe('toArray()', function() {
 	describe('Functional tests', function() {
 		dt.html('basic');
 		it('No array', function() {
-			let table = $('#example').DataTable();
+			table = $('#example').DataTable();
 			let array = table
 				.cells('.notThere')
 				.data()
 				.toArray();
 			expect(array.length).toBe(0);
 		});
-
 		it('Single array', function() {
-			let table = $('#example').DataTable();
 			let array = table
 				.column(0)
 				.data()
@@ -37,9 +35,7 @@ describe('toArray()', function() {
 			expect(array.length).toBe(57);
 			expect(array[0]).toBe('Airi Satou');
 		});
-
 		it('Multiple arrays', function() {
-			let table = $('#example').DataTable();
 			let array = table
 				.rows([2, 3])
 				.data()
