@@ -11,7 +11,7 @@ describe( "language.infoEmpty option", function() {
 			expect($('#example').DataTable().settings()[0].oLanguage.sInfoEmpty  == "Showing 0 to 0 of 0 entries").toBe(true);
 		});
 		it("Info empty language default is in the DOM", function () {
-			expect($('#example_info').html() == "Showing 1 to 10 of 57 entries").toBe(true);
+			expect($('div.dataTables_info').html() == "Showing 1 to 10 of 57 entries").toBe(true);
 		});
 		dt.html( 'basic' );
 		it("Info empty language can be defined", function () {
@@ -20,11 +20,11 @@ describe( "language.infoEmpty option", function() {
 					"infoEmpty": "unit test"
 				}
 			});
-			$('#example_filter input').val('asdasd').keyup();
+			$('div.dataTables_filter input').val('asdasd').keyup();
 			expect($('#example').DataTable().settings()[0].oLanguage.sInfoEmpty == "unit test").toBe(true);
 		});
 		it("Info empty language default is in the dom", function () {
-			expect($('#example_info').html() == "unit test (filtered from 57 total entries)").toBe(true);
+			expect($('div.dataTables_info').html() == "unit test (filtered from 57 total entries)").toBe(true);
 		});
 		dt.html( 'basic' );
 		it("Macro's replaced", function () {
@@ -33,8 +33,8 @@ describe( "language.infoEmpty option", function() {
 				"infoEmpty": "unit _START_ _END_ _TOTAL_ test"
 			}
 		});
-		$('#example_filter input').val('asdasd').keyup();
-		expect( $('#example_info').html() == "unit 1 0 0 test (filtered from 57 total entries)").toBe(true);
+		$('div.dataTables_filter input').val('asdasd').keyup();
+		expect( $('div.dataTables_info').html() == "unit 1 0 0 test (filtered from 57 total entries)").toBe(true);
 		});
 	});
 });
