@@ -13,7 +13,7 @@ describe( "language.loadingRecords option ", function() {
 					{ data: "name" },
 					{ data: "position" },
 					{ data: "office" },
-					{ data: "extn" },
+					{ data: "age" },
 					{ data: "start_date" },
 					{ data: "salary" }
 				],
